==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/table/lang/et.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'et', {
	border: 'Joone suurus',
	caption: 'Tabeli tiitel',
	cell: {
		menu: 'Lahter',
		insertBefore: 'Sisesta lahter enne',
		insertAfter: 'Sisesta lahter peale',
		deleteCell: 'Eemalda lahtrid',
		merge: 'Ühenda lahtrid',
		mergeRight: 'Ühenda paremale',
		mergeDown: 'Ühenda alla',
		splitHorizontal: 'Poolita lahter horisontaalselt',
		splitVertical: 'Poolita lahter vertikaalselt',
		title: 'Lahtri omadused',
		cellType: 'Lahtri liik',
		rowSpan: 'Ridade vahe',
		colSpan: 'Tulpade vahe',
		wordWrap: 'Sõnade murdmine',
		hAlign: 'Horisontaalne joondus',
		vAlign: 'Vertikaalne joondus',
		alignBaseline: 'Baasjoon',
		bgColor: 'Tausta värv',
		borderColor: 'Äärise värv',
		data: 'Andmed',
		header: 'Päis',
		yes: 'Jah',
		no: 'Ei',
		invalidWidth: 'Lahtri laius peab olema number.',
		invalidHeight: 'Lahtri kõrgus peab olema number.',
		invalidRowSpan: 'Ridade vahe peab olema täisarv.',
		invalidColSpan: 'Tulpade vahe peab olema täisarv.',
		chooseColor: 'Vali'
	},
	cellPad: 'Lahtri täidis',
	cellSpace: 'Lahtri vahe',
	column: {
		menu: 'Veerg',
		insertBefore: 'Sisesta veerg enne',
		insertAfter: 'Sisesta veerg peale',
		deleteColumn: 'Eemalda veerud'
	},
	columns: 'Veerud',
	deleteTable: 'Kustuta tabel',
	headers: 'Päised',
	headersBoth: 'Mõlemad',
	headersColumn: 'Esimene tulp',
	headersNone: 'Puudub',
	headersRow: 'Esimene rida',
	heightUnit: 'kõrgusühik',
	invalidBorder: 'Äärise suurus peab olema number.',
	invalidCellPadding: 'Lahtrite polsterdus (padding) peab olema positiivne arv.',
	invalidCellSpacing: 'Lahtrite vahe peab olema positiivne arv.',
	invalidCols: 'Tulpade arv peab olema nullist suurem.',
	invalidHeight: 'Tabeli kõrgus peab olema number.',
	invalidRows: 'Ridade arv peab olema nullist suurem.',
	invalidWidth: 'Tabeli laius peab olema number.',
	menu: 'Tabeli omadused',
	row: {
		menu: 'Rida',
		insertBefore: 'Sisesta rida enne',
		insertAfter: 'Sisesta rida peale',
		deleteRow: 'Eemalda read'
	},
	rows: 'Read',
	summary: 'Kokkuvõte',
	title: 'Tabeli omadused',
	toolbar: 'Tabel',
	widthPc: 'protsenti',
	widthPx: 'pikslit',
	widthUnit: 'laiuse ühik'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/et.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'et', {
	border: 'Joone suurus',
	caption: 'Tabeli tiitel',
	cell: {
		menu: 'Lahter',
		insertBefore: 'Sisesta lahter enne',
		insertAfter: 'Sisesta lahter peale',
		deleteCell: 'Eemalda lahtrid',
		merge: 'Ühenda lahtrid',
		mergeRight: 'Ühenda paremale',
		mergeDown: 'Ühenda alla',
		splitHorizontal: 'Poolita lahter horisontaalselt',
		splitVertical: 'Poolita lahter vertikaalselt',
		title: 'Lahtri omadused',
		cellType: 'Lahtri liik',
		rowSpan: 'Ridade vahe',
		colSpan: 'Tulpade vahe',
		wordWrap: 'Sõnade murdmine',
		hAlign: 'Horisontaalne joondus',
		vAlign: 'Vertikaalne joondus',
		alignBaseline: 'Baasjoon',
		bgColor: 'Tausta värv',
		borderColor: 'Äärise värv',
		data: 'Andmed',
		header: 'Päis',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Jah',
		no: 'Ei',
		invalidWidth: 'Lahtri laius peab olema number.',
		invalidHeight: 'Lahtri kõrgus peab olema number.',
		invalidRowSpan: 'Ridade vahe peab olema täisarv.',
		invalidColSpan: 'Tulpade vahe peab olema täisarv.',
		chooseColor: 'Vali'
	},
	cellPad: 'Lahtri täidis',
	cellSpace: 'Lahtri vahe',
	column: {
		menu: 'Veerg',
		insertBefore: 'Sisesta veerg enne',
		insertAfter: 'Sisesta veerg peale',
		deleteColumn: 'Eemalda veerud'
	},
	columns: 'Veerud',
	deleteTable: 'Kustuta tabel',
	headers: 'Päised',
	headersBoth: 'Mõlemad',
	headersColumn: 'Esimene tulp',
	headersNone: 'Puudub',
	headersRow: 'Esimene rida',
	heightUnit: 'kõrgusühik',
	invalidBorder: 'Äärise suurus peab olema number.',
	invalidCellPadding: 'Lahtrite polsterdus (padding) peab olema positiivne arv.',
	invalidCellSpacing: 'Lahtrite vahe peab olema positiivne arv.',
	invalidCols: 'Tulpade arv peab olema nullist suurem.',
	invalidHeight: 'Tabeli kõrgus peab olema number.',
	invalidRows: 'Ridade arv peab olema nullist suurem.',
	invalidWidth: 'Tabeli laius peab olema number.',
	menu: 'Tabeli omadused',
	row: {
		menu: 'Rida',
		insertBefore: 'Sisesta rida enne',
		insertAfter: 'Sisesta rida peale',
		deleteRow: 'Eemalda read'
	},
	rows: 'Read',
	summary: 'Kokkuvõte',
	title: 'Tabeli omadused',
	toolbar: 'Tabel',
	widthPc: 'protsenti',
	widthPx: 'pikslit',
	widthUnit: 'laiuse ühik'
} );
